# Roles' files and templates should not be mangled.
# These files are installed on remote systems which may or may not have the
# same file system layout as Fedora.
%global __brp_mangle_shebangs_exclude_from ^%{python3_sitelib}/ansible_collections/[^/]+/[^/]+/roles/[^/]+/(files|templates)/.*$
%global __requires_exclude_from %{?__requires_exclude_from:%__requires_exclude_from|}%{__brp_mangle_shebangs_exclude_from}

Name:		ansible
Summary:	SSH-based configuration management, deployment, and task execution system
Version:	9.9.0
Release:	%mkrel 2
Group:		Development/Python
License:	GPLv3
Url:		https://www.ansible.com/
Source0:	%{pypi_source}
Patch1:		ansible-reqs.patch
BuildArch:	noarch
BuildRequires:	openssl
BuildRequires:	pyproject-rpm-macros
BuildRequires:	python3-devel

# needed for json_query filter
Requires:	python3-jmespath

%description
Ansible is a radically simple model-driven configuration management,
multi-node deployment, and orchestration engine. Ansible works
over SSH and does not require any software or daemons to be installed
on remote nodes. Extension modules can be written in any language and
are transferred to managed machines automatically.

%prep
%autosetup -p1

%global py3_shbang_opts %{nil}
%py3_shebang_fix ansible_collections

# Fix wrong-script-end-of-line-encoding in azure.azcollection
find ansible_collections/azure/azcollection -type f -print -exec dos2unix -k '{}' \;

# Remove unnecessary files and directories included in the Ansible collection release tarballs
# Tracked upstream in part by: https://github.com/ansible-community/community-topics/issues/29
echo "[START] Delete unnecessary files and directories"

# Collection tarballs contain a lot of hidden files and directories
hidden_pattern=".*\.(DS_Store|all-contributorsrc|ansible-lint|azure-pipelines|circleci|codeclimate.yml|flake8|galaxy_install_info|gitattributes|github|gitignore|gitkeep|gitlab-ci.yml|idea|keep|mypy_cache|nojekyll|orig|plugin-cache.yaml|pre-commit-config.yaml|project|pydevproject|pytest_cache|pytest_cache|readthedocs.yml|settings|swp|travis.yml|vscode|yamllint|yamllint.yaml|zuul.d|zuul.yaml|rstcheck.cfg|placeholder)$"
find ansible_collections -depth -regextype posix-egrep -regex "${hidden_pattern}" -print -exec rm -r {} \;

# Not needed for runtime
rm -frv ansible_collections/cisco/meraki/scripts
rm -frv ansible_collections/community/grafana/hacking
rm -frv ansible_collections/community/okd/ci/
rm -frv ansible_collections/community/vmware/tools
rm -frv ansible_collections/cyberark/conjur/dev/
rm -frv ansible_collections/cyberark/conjur/roles/conjur_host_identity/tests/
rm -frv ansible_collections/netbox/netbox/hacking/
rm -frv ansible_collections/ovirt/ovirt/automation/
rm -frv ansible_collections/sensu/sensu_go/docker/
rm -fv ansible_collections/community/dns/update-psl.sh
rm -fv ansible_collections/cyberark/conjur/Jenkinsfile
rm -fv ansible_collections/dellemc/enterprise_sonic/rebuild.sh
rm -fv ansible_collections/ovirt/ovirt/build.sh

# rpmlint W: pem-certificate
find ansible_collections/cyberark/conjur -type f -name "*.pem" -print -delete

# rpmlint E: zero-length
find -type f -name "*requirements.txt" -size 0 -print -delete
rm -v ansible_collections/community/zabbix/roles/zabbix_agent/files/win_sample/doSomething.ps1
rm -v ansible_collections/community/docker/meta/ee-bindep.txt
rm -vr ansible_collections/ibm/spectrum_virtualize/roles/place_holder

echo "[END] Delete unnecessary files and directories"

###
# Fix various shebang related issues to appease brp-managle-shebangs
###
find ansible_collections/community/mongodb/roles/*/{files,templates} -type f '!' -executable -name '*.sh*' \
    -print -exec chmod a+x '{}' \;

# ansible_collections/lowlydba/sqlserver thought it was a good idea to make
# *every* single file, in its repository executable, including .md, .yml, and
# .rst. :facepalm:
#
# TODO: File issue upstream
find ansible_collections/lowlydba/sqlserver/ -executable -type f -print -exec chmod a-x '{}' \;

# Remove shebangs instead of hardocding to %%__python3 to avoid unexpected issues
# from https://github.com/ansible/ansible/commit/9142be2f6cabbe6597c9254c5bb9186d17036d55.
# Upstream, ansible-core has also removed shebangs from its modules.
#
# XXX: Print out the files before they're replaced
find -type f ! -executable -name '*.py' | tee non_exec
# xargs is noticably faster than find -exec, because it spawns one sed process
# instead of ~13 thousand!
xargs -a non_exec -d'\n' sed -i -e '1{\@^#!.*@d}'

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files ansible_collections

%files -f %{pyproject_files}
%license COPYING
%doc README*
%{_bindir}/%{name}-community


%changelog
* Mon Mar 03 2025 wally <wally> 9.9.0-2.mga10
+ Revision: 2160233
- rebuild for python3.13

* Wed Aug 28 2024 neoclust <neoclust> 9.9.0-1.mga10
+ Revision: 2091893
- New version 9.9.0

* Wed Dec 27 2023 papoteur <papoteur> 9.1.0-2.mga10
+ Revision: 2022212
- rebuild again for python 3.12

* Sun Dec 10 2023 wally <wally> 9.1.0-1.mga10
+ Revision: 2017043
- new version 9.1.0

* Thu Jan 26 2023 wally <wally> 7.1.0-1.mga9
+ Revision: 1936278
- new version 7.1.0
- sync with Fedora where appropriate

* Wed Mar 23 2022 umeabot <umeabot> 2.9.27-3.mga9
+ Revision: 1822522
- Mageia 9 Mass Rebuild

* Sun Feb 13 2022 neoclust <neoclust> 2.9.27-2.mga9
+ Revision: 1774198
- Rebuild for python 3.10

* Fri Oct 15 2021 luigiwalser <luigiwalser> 2.9.27-1.mga9
+ Revision: 1751619
- 2.9.27

* Wed Sep 15 2021 luigiwalser <luigiwalser> 2.9.26-1.mga9
+ Revision: 1745500
- 2.9.26

* Tue Aug 17 2021 luigiwalser <luigiwalser> 2.9.25-1.mga9
+ Revision: 1741780
- 2.9.25

* Fri Jul 23 2021 luigiwalser <luigiwalser> 2.9.24-1.mga9
+ Revision: 1737548
- 2.9.24

* Thu Jul 22 2021 neoclust <neoclust> 2.9.23-1.mga9
+ Revision: 1737390
- New version 2.9.23: Fixes  CVE-2021-3583 (mga#28832)

* Sat May 29 2021 bcornec <bcornec> 2.9.22-1.mga9
+ Revision: 1728799
- Update ansible to 2.9.22 upstream

* Mon May 03 2021 bcornec <bcornec> 2.9.20-1.mga9
+ Revision: 1721063
- Update to upstream ansible 2.9.20

* Sat Mar 20 2021 neoclust <neoclust> 2.9.18-2.mga9
+ Revision: 1705918
- Rebuild against python 3.9

* Thu Feb 25 2021 neoclust <neoclust> 2.9.18-1.mga9
+ Revision: 1690619
- New version 2.9.18 (mga#28436)

* Wed Jan 20 2021 luigiwalser <luigiwalser> 2.9.17-1.mga8
+ Revision: 1672613
- 2.9.17

* Tue Dec 15 2020 luigiwalser <luigiwalser> 2.9.16-1.mga8
+ Revision: 1657873
- 2.9.16

* Sun Nov 15 2020 luigiwalser <luigiwalser> 2.9.15-1.mga8
+ Revision: 1646411
- 2.9.15

* Wed Oct 14 2020 luigiwalser <luigiwalser> 2.9.14-1.mga8
+ Revision: 1636028
- 2.9.14

* Tue Sep 01 2020 bcornec <bcornec> 2.9.13-1.mga8
+ Revision: 1620727
- Update to upstream ansible 2.9.13 to fix mga#27175

* Sat Aug 22 2020 guillomovitch <guillomovitch> 2.9.12-1.mga8
+ Revision: 1617952
- new version 2.9.12

* Sun Aug 02 2020 guillomovitch <guillomovitch> 2.9.11-1.mga8
+ Revision: 1610572
- new version 2.9.11

* Sun May 17 2020 bcornec <bcornec> 2.9.9-1.mga8
+ Revision: 1585387
- Update to upstream ansible 2.9.9
+ danf <danf>
- Switch URLs from http: to https:

* Tue Mar 17 2020 bcornec <bcornec> 2.9.6-1.mga8
+ Revision: 1557123
- Update ansible to upstream 2.9.6 and fix mga#26349

* Mon Feb 17 2020 umeabot <umeabot> 2.9.5-2.mga8
+ Revision: 1537286
- Mageia 8 Mass Rebuild

* Sun Feb 16 2020 daviddavid <daviddavid> 2.9.5-1.mga8
+ Revision: 1533871
- new version: 2.9.5
- filter out bogus requires since new NM >= 1.22

* Mon Oct 28 2019 bcornec <bcornec> 2.8.6-3.mga8
+ Revision: 1456425
- Update to upstream ansible 2.8.6 to Fix mga#25607

* Sat Sep 14 2019 wally <wally> 2.8.2-3.mga8
+ Revision: 1440800
- drop pycrypto requires (cryptography is pulled via autodeps)

* Sat Sep 14 2019 daviddavid <daviddavid> 2.8.2-2.mga8
+ Revision: 1440716
- rebuild for python3.8

* Mon Aug 12 2019 bcornec <bcornec> 2.8.2-1.mga8
+ Revision: 1428844
- Update to upstream 2.8.2 and solves CVE-2019-10156

* Thu Apr 18 2019 bcornec <bcornec> 2.7.10-1.mga7
+ Revision: 1392797
- update to upstream ansible 2.7.10

* Mon Apr 01 2019 bcornec <bcornec> 2.7.9-1.mga7
+ Revision: 1383925
- update to upstream ansible 2.7.9

* Sun Mar 17 2019 bcornec <bcornec> 2.7.8-1.mga7
+ Revision: 1378310
- Update to upstream ansible 2.7.8

* Fri Feb 08 2019 daviddavid <daviddavid> 2.7.5-2.mga7
+ Revision: 1364188
- port to Python3
- no need to hard requires pkgs who are already auto-required

* Sat Dec 29 2018 bcornec <bcornec> 2.7.5-1.mga7
+ Revision: 1346427
- Fix mga#24065 by Updating to upstream ansible 2.7.5

* Sat Dec 22 2018 bcornec <bcornec> 2.7.0-3.mga7
+ Revision: 1344349
- Fix upstream ansible bug 47154 - https://github.com/ansible/ansible/issues/47154

* Wed Oct 10 2018 bcornec <bcornec> 2.7.0-2.mga7
+ Revision: 1319341
- Update to upstream ansible 2.7.0

* Thu Sep 20 2018 umeabot <umeabot> 2.5.5-2.mga7
+ Revision: 1277604
- Mageia 7 Mass Rebuild

* Mon Jun 25 2018 bcornec <bcornec> 2.5.5-1.mga7
+ Revision: 1239587
- Update to ansible upstream 2.5.5

* Thu May 17 2018 bcornec <bcornec> 2.5.2-1.mga7
+ Revision: 1230000
- Update to upstream ansible 2.5.2

* Tue Oct 31 2017 bcornec <bcornec> 2.4.1.0-3.mga7
+ Revision: 1175101
- Update to upstream 2.4.0.1

* Sat Sep 30 2017 guillomovitch <guillomovitch> 2.3.1.0-3.mga7
+ Revision: 1161869
- rebuild to generate proper automatic dependencies
+ bcornec <bcornec>
- Fix build script (minor)

* Sat Jun 03 2017 mitya <mitya> 2.3.1.0-1.mga6
+ Revision: 1106349
- New version 2.3.1.0

* Thu May 11 2017 bcornec <bcornec> 2.3.0.0-1.mga6
+ Revision: 1100145
- Fix mga#19740 by upgrading upstream to 2.3.0.0

* Sat Jan 28 2017 bcornec <bcornec> 2.2.1.0-1.mga6
+ Revision: 1083710
- Update to upstream ansible 2.2.1.0 to fix multiple CVEs

* Sun Nov 20 2016 bcornec <bcornec> 2.2.0.0-1.mga6
+ Revision: 1068498
- Fix #19740 by upgrading to upstream 2.2.0.0

* Sat Sep 03 2016 bcornec <bcornec> 2.1.1.0-1.mga6
+ Revision: 1049859
- Update ansible to upstream 2.1.1

* Fri Apr 22 2016 bcornec <bcornec> 2.0.2.0-1.mga6
+ Revision: 1005372
- Update to upstream 2.0.2.0

* Sun Jan 03 2016 bcornec <bcornec> 1.9.4-1.mga6
+ Revision: 919094
- Update to upstream 1.9.4

* Sun Jul 12 2015 bcornec <bcornec> 1.9.2-1.mga6
+ Revision: 853431
- ANd sha1 update !
- Update to upstream 1.9.2 (Fixes #16309)

* Fri Dec 05 2014 bcornec <bcornec> 1.8.1-1.mga5
+ Revision: 801606
- Update to upstream 1.8.1

* Thu Oct 16 2014 bcornec <bcornec> 1.7.2-1.mga5
+ Revision: 758892
- Update to upstream ansible 1.7.2
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.7.1-3.mga5
+ Revision: 725940
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.7.1-2.mga5
+ Revision: 677767
- Mageia 5 Mass Rebuild

* Mon Sep 01 2014 bcornec <bcornec> 1.7.1-1.mga5
+ Revision: 670239
- Update to ansibla 1.7.1 upstream

* Mon Aug 11 2014 bcornec <bcornec> 1.7-1.mga5
+ Revision: 661832
- Update to upstream ansible 1.7

* Sun Aug 10 2014 bcornec <bcornec> 1.6.10-1.mga5
+ Revision: 661315
- Update to upstream 1.6.10 to fixing security issues

* Thu Jul 24 2014 bcornec <bcornec> 1.6.8-3.mga5
+ Revision: 656219
- python-setuptools is a BuildRequire of course !
- ansible now requires python-setuptools to build correctly
- Update to upstream 1.6.8

* Sat May 31 2014 pterjan <pterjan> 1.5.5-2.mga5
+ Revision: 628100
- Rebuild for new Python

* Tue Apr 29 2014 bcornec <bcornec> 1.5.5-1.mga5
+ Revision: 618792
- Update ansible to 1.5.5 upstream
- No man3 man pages provided anymore so remove their copy

* Wed Jan 22 2014 bcornec <bcornec> 1.4.3-1.mga5
+ Revision: 567445
- Update to upstream 1.4.3

* Tue Dec 03 2013 bcornec <bcornec> 1.4.1-1.mga4
+ Revision: 554733
- Update to upstream 1.4.1

* Sat Nov 23 2013 bcornec <bcornec> 1.4-1.mga4
+ Revision: 552390
- Update to upstream ansible 1.4

* Mon Nov 11 2013 philippem <philippem> 1.3.4-4.mga4
+ Revision: 550500
- Add Requires python-keyczar on main package for accelerated mode

* Sun Nov 03 2013 bcornec <bcornec> 1.3.4-3.mga4
+ Revision: 549294
- Update to upstream 1.3.4

* Tue Oct 22 2013 umeabot <umeabot> 1.3.2-3.mga4
+ Revision: 542481
- Mageia 4 Mass Rebuild

* Mon Oct 14 2013 pterjan <pterjan> 1.3.2-2.mga4
+ Revision: 497632
- Rebuild to add different pythonegg provides for python 2 and 3

* Tue Oct 08 2013 bcornec <bcornec> 1.3.2-1.mga4
+ Revision: 493040
- Update ansible to 1.3.2 upstream

* Mon Sep 09 2013 bcornec <bcornec> 1.2.3-2.mga4
+ Revision: 476539
- Push reltag to 2 for ansible as previous patches consequence
- Do not generate the 0mq packages for now as zeromq is not in Mageia yet and SSH can be used
- Update Group in SPEC file for ansible
- Update sha for ansible
- Import from Fedora the ansible package
- Created package structure for ansible.

